/*
 * Copyright (C) 2008-2009 Alex Lasnier <alex@fepg.org>
 *
 * This file is part of NAScan
 *
 * NAScan is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * NAScan is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NAScan.  If not, see <http://www.gnu.org/licenses/>.
 */
 
#ifndef __NASCAN_NIT_FILTER_H
#define __NASCAN_NIT_FILTER_H

#include <set>

#include "filter.h"


//////////////////////////////////////////////////////////////////////////////


class TransponderSorter : public cListObject 
{
public:
  cChannel* channel;

  TransponderSorter(cChannel* Channel) { channel = Channel; }
  virtual ~TransponderSorter() { delete channel; }
  
  virtual int Compare(const cListObject &ListObject) const 
  {
    TransponderSorter* cs = (TransponderSorter*) &ListObject;
    return (channel->Frequency() - cs->channel->Frequency());
  }
};


//////////////////////////////////////////////////////////////////////////////


class NitFilter : public GFilter
{
public:
  NitFilter(cList<TransponderSorter>* tl);
  virtual ~NitFilter();
  
  bool GotNit(void) const { return gotNit; }
  bool GotData(void) { bool ret = gotData; gotData = false; return ret; }
  
protected:
  virtual void Process(u_short pid, u_char tid, const u_char* data, int length); 
  virtual void SetStatus(bool On);
    
private:
  bool GotSection(int i) const;
  bool GotAllSections(void) const;
  void SeenSection(int i);
  
  void AddTransponder(int Source, int Nid, int Tid, int Frequency, char Polarization, int Srate, int CoderateH, int Modulation, int System, int RollOff);
  
  bool gotNit;
  bool gotData;
  
  int numSections;
  uint64_t sections; // 63 sections max
  
  cList<TransponderSorter>* transponderList;
};


//////////////////////////////////////////////////////////////////////////////


#endif // __NASCAN_NIT_FILTER_H
